==> xwiki-rendering-api-4.0-milestone-2-sources.jar: org/xwiki/rendering/renderer/PrintRendererFactory.java <==
/*
 * See the NOTICE file distributed with this work for additional
 * information regarding copyright ownership.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.xwiki.rendering.renderer;

import org.xwiki.component.annotation.ComponentRole;
import org.xwiki.rendering.syntax.Syntax;
import org.xwiki.rendering.renderer.printer.WikiPrinter;

/**
 * Allows creating {@link Renderer}s of a given type (one factory implementation per Renderer type).
 * We need a factory since we need to pass a {@link WikiPrinter} object to the created Renderer. In addition this
 * factory allows us to be able to return the {@link org.xwiki.rendering.syntax.Syntax} supported by the Renderer without needing to create an
 * instance of it.
 * 
 * @version $Id: 837378d0b3a2da8918eb78dd977fa9e2acf85262 $
 * @since 1.6M2
 */
@ComponentRole
public interface PrintRendererFactory
{
    /**
     * @return the Syntax supported by the Renderer type
     * @since 2.0M3
     */
    Syntax getSyntax();

    /**
     * @param printer the printer to use to output renderer data
     * @return a new Renderer instance (stateful)
     * @since 2.0M3
     */
    PrintRenderer createRenderer(WikiPrinter printer);
}

==> xwiki-rendering-api-4.1-milestone-2-sources.jar: org/xwiki/rendering/renderer/PrintRendererFactory.java <==
/*
 * See the NOTICE file distributed with this work for additional
 * information regarding copyright ownership.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.xwiki.rendering.renderer;

import org.xwiki.component.annotation.Role;
import org.xwiki.rendering.syntax.Syntax;
import org.xwiki.rendering.renderer.printer.WikiPrinter;

/**
 * Allows creating {@link Renderer}s of a given type (one factory implementation per Renderer type).
 * We need a factory since we need to pass a {@link WikiPrinter} object to the created Renderer. In addition this
 * factory allows us to be able to return the {@link org.xwiki.rendering.syntax.Syntax} supported by the Renderer without needing to create an
 * instance of it.
 * 
 * @version $Id$
 * @since 1.6M2
 */
@Role
public interface PrintRendererFactory
{
    /**
     * @return the Syntax supported by the Renderer type
     * @since 2.0M3
     */
    Syntax getSyntax();

    /**
     * @param printer the printer to use to output renderer data
     * @return a new Renderer instance (stateful)
     * @since 2.0M3
     */
    PrintRenderer createRenderer(WikiPrinter printer);
}
